What’s new in version 1.0.2
===========================
Version available since October 17th 2021


Changes
------------
- "noload" package renamed "noloadj" to avoid issues with NoLOAD library.

Contributors
------------
Lucas Agobert
